@@ -82,6 +82,8 @@ sub run
     }
 
     my $cv = AE::cv;
+    AnyEvent::Loop::now_update();
+
     my ( @work, $stop );
 
     $SIG{TERM} = $SIG{INT} = my $tocb = sub
@@ -138,7 +140,7 @@ sub run
              );
              $hdl->push_write($query);
              $hdl->push_shutdown;
-          };
+          }, sub{ return 3; };
     };
 
     my $max = scalar @node > $run{max} ? $run{max} : scalar @node;
@@ -237,7 +239,7 @@ sub run
              );
              $hdl->push_write($rquery);
              $hdl->push_shutdown;
-          };
+          }, sub{ return 3; };
     };
 
     #Don't change it to map
